==> kubernetes-model-1.0.60-sources.jar: io/fabric8/openshift/api/model/DeploymentDetailsBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class DeploymentDetailsBuilder extends DeploymentDetailsFluentImpl<DeploymentDetailsBuilder> implements VisitableBuilder<DeploymentDetails,DeploymentDetailsBuilder>{

    DeploymentDetailsFluent<?> fluent;
    Boolean validationEnabled;

    public DeploymentDetailsBuilder(){
            this(true);
    }
    public DeploymentDetailsBuilder(Boolean validationEnabled){
            this(new DeploymentDetails(), validationEnabled);
    }
    public DeploymentDetailsBuilder(DeploymentDetailsFluent<?> fluent){
            this(fluent, true);
    }
    public DeploymentDetailsBuilder(DeploymentDetailsFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new DeploymentDetails(), validationEnabled);
    }
    public DeploymentDetailsBuilder(DeploymentDetailsFluent<?> fluent,DeploymentDetails instance){
            this(fluent, instance, true);
    }
    public DeploymentDetailsBuilder(DeploymentDetailsFluent<?> fluent,DeploymentDetails instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withCauses(instance.getCauses()); 
            fluent.withMessage(instance.getMessage()); 
            this.validationEnabled = validationEnabled; 
    }
    public DeploymentDetailsBuilder(DeploymentDetails instance){
            this(instance,true);
    }
    public DeploymentDetailsBuilder(DeploymentDetails instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withCauses(instance.getCauses()); 
            this.withMessage(instance.getMessage()); 
            this.validationEnabled = validationEnabled; 
    }

    public DeploymentDetails build(){
            DeploymentDetails buildable = new DeploymentDetails(fluent.getCauses(),fluent.getMessage());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            DeploymentDetailsBuilder that = (DeploymentDetailsBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-2.0.9-sources.jar: io/fabric8/openshift/api/model/DeploymentDetailsBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class DeploymentDetailsBuilder extends DeploymentDetailsFluentImpl<DeploymentDetailsBuilder> implements VisitableBuilder<DeploymentDetails,DeploymentDetailsBuilder>{

    DeploymentDetailsFluent<?> fluent;
    Boolean validationEnabled;

    public DeploymentDetailsBuilder(){
            this(true);
    }
    public DeploymentDetailsBuilder(Boolean validationEnabled){
            this(new DeploymentDetails(), validationEnabled);
    }
    public DeploymentDetailsBuilder(DeploymentDetailsFluent<?> fluent){
            this(fluent, true);
    }
    public DeploymentDetailsBuilder(DeploymentDetailsFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new DeploymentDetails(), validationEnabled);
    }
    public DeploymentDetailsBuilder(DeploymentDetailsFluent<?> fluent,DeploymentDetails instance){
            this(fluent, instance, true);
    }
    public DeploymentDetailsBuilder(DeploymentDetailsFluent<?> fluent,DeploymentDetails instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withCauses(instance.getCauses()); 
            fluent.withMessage(instance.getMessage()); 
            this.validationEnabled = validationEnabled; 
    }
    public DeploymentDetailsBuilder(DeploymentDetails instance){
            this(instance,true);
    }
    public DeploymentDetailsBuilder(DeploymentDetails instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withCauses(instance.getCauses()); 
            this.withMessage(instance.getMessage()); 
            this.validationEnabled = validationEnabled; 
    }

    public DeploymentDetails build(){
            DeploymentDetails buildable = new DeploymentDetails(fluent.getCauses(),fluent.getMessage());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            DeploymentDetailsBuilder that = (DeploymentDetailsBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
